@@ -7,6 +7,7 @@ __all__ = [
     "TopologyGreedy",
     "AgentWithConverter",
     "RandomAgent",
+    "DeltaRedispatchRandomAgent",
     "MLAgent",
     "RecoPowerlineAgent"
 ]
@@ -19,5 +20,6 @@ from grid2op.Agent.PowerlineSwitch import PowerLineSwitch
 from grid2op.Agent.TopologyGreedy import TopologyGreedy
 from grid2op.Agent.AgentWithConverter import AgentWithConverter
 from grid2op.Agent.RandomAgent import RandomAgent
+from grid2op.Agent.DeltaRedispatchRandomAgent import DeltaRedispatchRandomAgent
 from grid2op.Agent.MLAgent import MLAgent
 from grid2op.Agent.RecoPowerlineAgent import RecoPowerlineAgent
