@@ -28,6 +28,8 @@ class Backend(GridObjects, ABC):
     This class allow the user or the agent to interact with an power flow calculator, while relying on dedicated
     methods to change the power grid behaviour.
 
+    It is NOT recommended to use this class outside the Environment.
+
     An example of a valid backend is provided in the :class:`PandapowerBackend`.
 
     All the abstract methods (that need to be implemented for a backend to work properly) are:
@@ -50,6 +52,11 @@ class Backend(GridObjects, ABC):
     should also be implemented.
 
 
+    In order to be valid and carry out some computations, you should call :func:`Backend.load_grid` and later
+    :func:`grid2op.Spaces.GridObjects.assert_grid_correct`. It is also more than recommended to call
+    :func:`Backend.assert_grid_correct_after_powerflow` after the first powerflow. This is all carried ou in the
+    environment properly.
+
     Attributes
     ----------
     detailed_infos_for_cascading_failures: :class:`bool`
@@ -314,7 +321,7 @@ class Backend(GridObjects, ABC):
         """
         if isinstance(limits, np.ndarray):
             if limits.shape[0] == self.n_line:
-                self.thermal_limit_a = 1. * limits
+                self.thermal_limit_a = 1. * limits.astype(dt_float)
         elif isinstance(limits, dict):
             for el in limits.keys():
                 if not el in self.name_line:
@@ -416,20 +423,17 @@ class Backend(GridObjects, ABC):
 
         For each elements, it gives on which bus it is connected in its substation.
 
-        For example, if the first element of this vector is the load of id 1, then if `res[0] = 2` it means that the
-        load of id 1 is connected to the second bus of its substation.
+        For example, if the first element of this vector is the load of id 1, then if `res[0] = 2` it means that the load of id 1 is connected to the second bus of its substation.
 
-        You can check which object of the powerlines is represented by each component of this vector by looking at the
-        `*_pos_topo_vect` (*eg.* :attr:`grid2op.Space.GridObjects.load_pos_topo_vect`) vectors.
+        You can check which object of the powerlines is represented by each component of this vector by looking at the `*_pos_topo_vect` (*eg.* :attr:`grid2op.Space.GridObjects.load_pos_topo_vect`) vectors.
         For each elements it gives its position in this vector.
 
-        As any function of the backend, it is not advised to use it directly. You can get this information in the
-        :attr:`grid2op.Observation.Observation.topo_vect`instead.
+        As any function of the backend, it is not advised to use it directly. You can get this information in the :attr:`grid2op.Observation.Observation.topo_vect` instead.
 
         Returns
         --------
 
-        res: `numpy.ndarray`, dtype: ``int``
+        res: ``numpy.ndarray`` dtype: ``int``
             An array saying to which bus the object is connected.
 
         """
@@ -545,7 +549,7 @@ class Backend(GridObjects, ABC):
         raise Grid2OpException("This backend doesn't allow to get the substation from the bus id.")
 
     @abstractmethod
-    def _disconnect_line(self, id):
+    def _disconnect_line(self, id_):
         """
         Disconnect the line of id "id" in the backend.
         In this scenario, the *id* of a powerline is its position (counted starting from O) in the vector returned by
@@ -639,7 +643,6 @@ class Backend(GridObjects, ABC):
 
             # perform the disconnection action
             [self._disconnect_line(i) for i, el in enumerate(to_disc) if el]
-
             # start a powerflow on this new state
             conv_ = self._runpf_with_diverging_exception(is_dc)
             if self.detailed_infos_for_cascading_failures:
