@@ -8,11 +8,12 @@
 
 import time
 import numpy as np
+import copy
 from scipy.optimize import minimize
 from scipy.optimize import LinearConstraint
 from abc import ABC, abstractmethod
 
-from grid2op.dtypes import dt_int, dt_float
+from grid2op.dtypes import dt_int, dt_float, dt_bool
 from grid2op.Space import GridObjects, RandomObject
 from grid2op.Exceptions import *
 from grid2op.Parameters import Parameters
@@ -849,14 +850,15 @@ class BaseEnv(GridObjects, RandomObject, ABC):
         attack_duration = 0
         lines_attacked, subs_attacked = None, None
         conv_ = None
+        init_line_status = copy.deepcopy(self.backend.get_line_status())
         try:
-            # "smart" reconnecting
             beg_ = time.time()
-            is_illegal = not self.game_rules(action=action, env=self)
-            if is_illegal:
+            is_legal, reason = self.game_rules(action=action, env=self)
+            if not is_legal:
                 # action is replace by do nothing
                 action = self.helper_action_player({})
-                except_.append(IllegalAction("BaseAction illegal"))
+                except_.append(reason)
+                is_illegal = True
 
             ambiguous, except_tmp = action.is_ambiguous()
             if ambiguous:
@@ -902,12 +904,8 @@ class BaseEnv(GridObjects, RandomObject, ABC):
             self._backend_action += action
             action._redispatch[:] = init_disp
 
-            self.env_modification._redispatch[:] = self.actual_dispatch
             self._backend_action += self.env_modification
-
-            # action, for redispatching is composed of multiple actions, so basically i won't check
-            # ramp_min and ramp_max
-            self.env_modification._single_act = False
+            self._backend_action.set_redispatch(self.actual_dispatch)
 
             # now get the new generator voltage setpoint
             voltage_control_act = self._voltage_control(action, prod_v_chronics)
@@ -918,8 +916,8 @@ class BaseEnv(GridObjects, RandomObject, ABC):
             # included in time_apply_act
             tick = time.time()
             attack, attack_duration = self.oppSpace.attack(observation=self.current_obs,
-                                                            agent_action=action,
-                                                            env_action=self.env_modification)
+                                                           agent_action=action,
+                                                           env_action=self.env_modification)
             if attack is not None:
                 # the opponent choose to attack
                 # i update the "cooldown" on these things
@@ -959,7 +957,7 @@ class BaseEnv(GridObjects, RandomObject, ABC):
                     self.timestep_overflow[~overflow_lines] = 0
 
                     # build the topological action "cooldown"
-                    aff_lines, aff_subs = action.get_topological_impact()
+                    aff_lines, aff_subs = action.get_topological_impact(init_line_status)
                     if self.max_timestep_line_status_deactivated > 0:
                         # i update the cooldown only when this does not impact the line disconnected for the
                         # opponent or by maitnenance for example
@@ -1025,6 +1023,12 @@ class BaseEnv(GridObjects, RandomObject, ABC):
                          }
         return res, other_rewards
 
+    def get_reward_instance(self):
+        """
+        Returns the instance of the object that is used to compute the reward.
+        """
+        return self.reward_helper.template_reward
+
     def _is_done(self, has_error, is_done):
         no_more_data = self.chronics_handler.done()
         return has_error or is_done or no_more_data
@@ -1177,3 +1181,12 @@ class BaseEnv(GridObjects, RandomObject, ABC):
 
         # Update to the fast forward state using a do nothing action
         self.step(self.helper_action_player({}))
+
+    def get_current_line_status(self):
+        """internal, do not use outside of "Rules" or simulate etc."""
+        if self.current_obs is not None:
+            powerline_status = self.current_obs.line_status
+        else:
+            # at first time step, every powerline is connected
+            powerline_status = np.full(self.n_line, fill_value=True, dtype=dt_bool)
+        return powerline_status
\ No newline at end of file
