@@ -106,7 +106,7 @@ class MultiMixEnvironment(GridObjects, RandomObject):
 
     def __next__(self):
         if self.env_index < len(self.mix_envs):
-            r =  self.mix_envs[self.env_index]
+            r = self.mix_envs[self.env_index]
             self.env_index = self.env_index + 1
             return r
         else:
@@ -128,9 +128,29 @@ class MultiMixEnvironment(GridObjects, RandomObject):
         for mix in self.mix_envs:
             yield mix.name, mix
 
+    def copy(self):
+        mix_envs = self.mix_envs
+        self.mix_envs = None
+        current_env = self.current_env
+        self.current_env = None
+
+        cls = self.__class__
+        res = cls.__new__(cls)
+        for k in self.__dict__:
+            if k == "mix_envs" or k == "current_env":
+                # this is handled elswhere
+                continue
+            setattr(res, k, copy.deepcopy(getattr(self, k)))
+        res.mix_envs = [mix.copy() for mix in mix_envs]
+        res.current_env = res.mix_envs[res.env_index]
+
+        self.mix_envs = mix_envs
+        self.current_env = current_env
+        return res
+
     def __getitem__(self, key):
         """
-        Operator [] overload for accesing underlying mixes by name
+        Operator [] overload for accessing underlying mixes by name
 
         .. code-block:: python
 
