@@ -5,6 +5,7 @@ __all__ = [
     "list_available_local_env",
     "get_current_local_dir",
     "change_local_dir",
+    "update_env",
     # deprecated in v 0.8.0
     "make_old"
 ]
@@ -13,3 +14,4 @@ from grid2op.MakeEnv.MakeOld import make_old
 from grid2op.MakeEnv.MakeFromPath import make_from_dataset_path
 from grid2op.MakeEnv.Make import make
 from grid2op.MakeEnv.UserUtils import list_available_remote_env, list_available_local_env, get_current_local_dir, change_local_dir
+from grid2op.MakeEnv.UpdateEnv import update_env
