@@ -304,8 +304,6 @@ class BaseObservation(GridObjects):
                   of this next maintenance.
                 - "cooldown_time": for how many timestep i am not supposed to act on the powerline due to cooldown
                   (see :attr:`grid2op.Parameters.Parameters.NB_TIMESTEP_LINE_STATUS_REMODIF` for more information)
-                - "indisponibility": for how many timestep the powerline is unavailable (disconnected, and it's
-                  impossible to reconnect it) due to hazards, maintenance or overflow (incl. cascading failure)
 
             - if a substation is inspected, it returns the topology to this substation in a dictionary with keys:
 
@@ -663,20 +661,20 @@ class BaseObservation(GridObjects):
         """
         if time_step >= len(self._forecasted_inj):
             raise NoForecastAvailable("Forecast for {} timestep ahead is not possible with your chronics.".format(time_step))
-        a = self._forecasted_grid_act[time_step]["inj_action"]
+        t, a = self._forecasted_inj[time_step]
         prod_p_f = np.full(self.n_gen, fill_value=np.NaN, dtype=dt_float)
         prod_v_f = np.full(self.n_gen, fill_value=np.NaN, dtype=dt_float)
         load_p_f = np.full(self.n_load, fill_value=np.NaN, dtype=dt_float)
         load_q_f = np.full(self.n_load, fill_value=np.NaN, dtype=dt_float)
 
-        if "prod_p" in a._dict_inj:
-            prod_p_f = a._dict_inj["prod_p"]
-        if "prod_v" in a._dict_inj:
-            prod_v_f = a._dict_inj["prod_v"]
-        if "load_p" in a._dict_inj:
-            load_p_f = a._dict_inj["load_p"]
-        if "load_q" in a._dict_inj:
-            load_q_f = a._dict_inj["load_q"]
+        if "prod_p" in a["injection"]:
+            prod_p_f = a["injection"]["prod_p"]
+        if "prod_v" in a["injection"]:
+            prod_v_f = a["injection"]["prod_v"]
+        if "load_p" in a["injection"]:
+            load_p_f = a["injection"]["load_p"]
+        if "load_q" in a["injection"]:
+            load_q_f = a["injection"]["load_q"]
         tmp_arg = ~np.isfinite(prod_p_f)
         prod_p_f[tmp_arg] = self.prod_p[tmp_arg]
         tmp_arg = ~np.isfinite(prod_v_f)
