@@ -13,8 +13,8 @@ class GameplayReward(BaseReward):
     """
     This rewards is strictly computed based on the Game status.
     It yields a negative reward in case of game over.
-    A positive reward if the game is won (finished an episode)
-    Otherwise the reward is zero
+    A half negative reward on rules infringment.
+    Otherwise the reward is positive.
     """
     def __init__(self):
         BaseReward.__init__(self)
@@ -23,9 +23,11 @@ class GameplayReward(BaseReward):
 
     def __call__(self, action, env, has_error,
                  is_done, is_illegal, is_ambiguous):
-        if has_error or is_illegal or is_ambiguous:
-            # Broke the game or did not respect the rules
+        if has_error:
             return self.reward_min
+        elif is_illegal or is_ambiguous:
+            # Did not respect the rules
+            return self.reward_min / dt_float(2.0)
         else:
             # Keep playing or finished episode
             return self.reward_max
