@@ -10,7 +10,7 @@ import numpy as np
 
 from grid2op.Exceptions import Grid2OpException
 from grid2op.Reward.BaseReward import BaseReward
-
+from grid2op.dtypes import dt_float
 
 class RedispReward(BaseReward):
     """
@@ -21,30 +21,30 @@ class RedispReward(BaseReward):
         BaseReward.__init__(self)
         self.reward_min = None
         self.reward_max = None
-        self.max_regret = 0.
-        self.alpha_redisph = alpha_redisph
+        self.max_regret = dt_float(0.0)
+        self.alpha_redisph = dt_float(alpha_redisph)
 
     def initialize(self, env):
         if not env.redispatching_unit_commitment_availble:
             raise Grid2OpException("Impossible to use the RedispReward reward with an environment without generators"
                                    "cost. Please make sure env.redispatching_unit_commitment_availble is available.")
         worst_marginal_cost = np.max(env.gen_cost_per_MW)
-        worst_load = np.sum(env.gen_pmax)
-        worst_losses = 0.05 * worst_load  # it's not the worst, but definitely an upper bound
+        worst_load = dt_float(np.sum(env.gen_pmax))
+        worst_losses = dt_float(0.05) * worst_load  # it's not the worst, but definitely an upper bound
         worst_redisp = self.alpha_redisph * np.sum(env.gen_pmax)  # not realistic, but an upper bound
         self.max_regret = (worst_losses + worst_redisp)*worst_marginal_cost
-        self.reward_min = -10
+        self.reward_min = dt_float(-10.0)
 
-        least_loads = (worst_load * 0.5)  # half the capacity of the grid
-        least_losses = 0.015 * least_loads  # 1.5% of losses
-        least_redisp = 0.  # lower_bound is 0
+        least_loads = dt_float(worst_load * 0.5)  # half the capacity of the grid
+        least_losses = dt_float(0.015 * least_loads)  # 1.5% of losses
+        least_redisp = dt_float(0.0)  # lower_bound is 0
         base_marginal_cost = np.min(env.gen_cost_per_MW[env.gen_cost_per_MW > 0.])
         min_regret = (least_losses + least_redisp) * base_marginal_cost
-        self.reward_max = (self.max_regret - min_regret) / least_loads
+        self.reward_max = dt_float((self.max_regret - min_regret) / least_loads)
 
     def __call__(self,  action, env, has_error, is_done, is_illegal, is_ambiguous):
         if has_error or is_illegal or is_ambiguous:
-            res = self.reward_min * 0.5
+            res = self.reward_min
         else:
             # compute the losses
             gen_p, *_ = env.backend.generators_info()
@@ -67,6 +67,6 @@ class RedispReward(BaseReward):
             reward = self.max_regret - regret
 
             # divide it by load, to be less sensitive to load variation
-            res = reward / np.sum(load_p)
+            res = dt_float(reward / np.sum(load_p))
 
         return res
