@@ -8,6 +8,7 @@
 import time
 import warnings
 
+import sys
 import numpy as np
 import copy
 
@@ -27,10 +28,13 @@ from grid2op.Agent import DoNothingAgent, BaseAgent
 from grid2op.Episode import EpisodeData
 from grid2op.Runner.FakePBar import _FakePbar
 from grid2op.VoltageControler import ControlVoltageFromFile
-from grid2op.Opponent import BaseOpponent
 from grid2op.dtypes import dt_float
-from grid2op.Space import RandomObject
+from grid2op.Opponent import BaseOpponent, NeverAttackBudget
 
+# on windows if i start using sequential, i need to continue using sequential
+# if i start using parallel i need to continue using parallel
+# so i force the usage of the "starmap" stuff even if there is one process on windows
+_IS_WINDOWS = sys.platform.startswith('win')
 
 # TODO have a vectorized implementation of everything in case the agent is able to act on multiple environment
 # at the same time. This might require a lot of work, but would be totally worth it! (especially for Neural Net based agents)
@@ -38,7 +42,7 @@ from grid2op.Space import RandomObject
 # TODO add a more suitable logging strategy
 
 # TODO use gym logger if specified by the user.
-
+# TODO: if chronics are "loop through" multiple times, only last results are saved. :-/
 
 class DoNothingLog:
     """
@@ -100,8 +104,6 @@ class ConsoleLog(DoNothingLog):
             if kwargs:
                 print("WARNING: {}".format(kwargs))
 
-#TODO i think runner.env are not close, like, never closed :eyes:
-
 
 class Runner(object):
     """
@@ -199,14 +201,30 @@ class Runner(object):
     thermal_limit_a: ``numpy.ndarray``
         The thermal limit for the environment (if any).
 
-    seed: ``int``
-        The seed used, for reproducible experiments (**NB** to ensure reproducible experiments even in the case of
-        parallel evaluation, there are absolutely not warrantee the seed used by any of the envrionment generated
-        will be the seed passed in this parameter.)
+    opponent_action_class: ``type``, optional
+        The action class used for the opponent. The opponent will not be able to use action that are invalid with
+        the given action class provided. It defaults to :class:`grid2op.Action.DontAct` which forbid any type
+        of action possible.
+
+    opponent_class: ``type``, optional
+        The opponent class to use. The default class is :class:`grid2op.Opponent.BaseOpponent` which is a type
+        of opponents that does nothing.
+
+    opponent_init_budget: ``float``, optional
+        The initial budget of the opponent. It defaults to 0.0 which means the opponent cannot perform any action
+        if this is not modified.
+
+    opponent_budget_per_ts: ``float``, optional
+        The budget increase of the opponent per time step
+
+    opponent_budget_class: ``type``, optional
+        The class used to compute the attack cost.
+
+    grid_layout: ``dict``, optional
+        The layout of the grid (position of each substation) usefull if you need to plot some things for example.
     """
 
     def __init__(self,
-                 # full path where grid state is located, eg "./data/test_Pandapower/case14.json"
                  init_grid_path: str,
                  path_chron,  # path where chronics of injections are stored
                  name_env="unknown",
@@ -230,8 +248,14 @@ class Runner(object):
                  other_rewards={},
                  opponent_action_class=DontAct,
                  opponent_class=BaseOpponent,
-                 opponent_init_budget=0,
-                 grid_layout=None):
+                 opponent_init_budget=0.,
+                 opponent_budget_per_ts=0.,
+                 opponent_budget_class=NeverAttackBudget,
+                 opponent_attack_duration=0,
+                 opponent_attack_cooldown=99999,
+                 opponent_kwargs={},
+                 grid_layout=None,
+                 with_forecast=True):
         """
         Initialize the Runner.
 
@@ -288,16 +312,9 @@ class Runner(object):
         voltagecontrolerClass: :class:`grid2op.VoltageControler.ControlVoltageFromFile`, optional
             The controler that will change the voltage setpoints of the generators.
 
-        forbid_dispatch_off: ``bool``
-            Whether or not you forbid to apply dispacthing action on turned off generator (default False)
-
-        ignore_min_up_down_times: ``bool``
-            Whether or not to ignore gen_min_uptime and gen_min_downtime when applying redispatching actions.
-            (default True)
-
-        seed: ``int``
-            Seed used (default ``None``)
+        # TODO documentation on the opponent
         """
+        self.with_forecast = with_forecast
         self.name_env = name_env
         if not isinstance(envClass, type):
             raise Grid2OpException(
@@ -466,13 +483,23 @@ class Runner(object):
         self.opponent_action_class = opponent_action_class
         self.opponent_class = opponent_class
         self.opponent_init_budget = opponent_init_budget
+        self.opponent_budget_per_ts = opponent_budget_per_ts
+        self.opponent_budget_class = opponent_budget_class
+        self.opponent_attack_duration = opponent_attack_duration
+        self.opponent_attack_cooldown = opponent_attack_cooldown
+        self.opponent_kwargs = opponent_kwargs
+
         self.grid_layout = grid_layout
 
+        # otherwise on windows it sometimes fail in the runner in multi process
+        # self.init_env()
+
     def _new_env(self, chronics_handler, backend, parameters):
         res = self.envClass(init_grid_path=self.init_grid_path,
                             chronics_handler=chronics_handler,
                             backend=backend,
                             parameters=parameters,
+                            name=self.name_env,
                             names_chronics_to_backend=self.names_chronics_to_backend,
                             actionClass=self.actionClass,
                             observationClass=self.observationClass,
@@ -480,10 +507,20 @@ class Runner(object):
                             legalActClass=self.legalActClass,
                             voltagecontrolerClass=self.voltageControlerClass,
                             other_rewards=self._other_rewards,
+
                             opponent_action_class=self.opponent_action_class,
                             opponent_class=self.opponent_class,
                             opponent_init_budget=self.opponent_init_budget,
-                            name=self.name_env)
+                            opponent_budget_per_ts=self.opponent_budget_per_ts,
+                            opponent_budget_class=self.opponent_budget_class,
+                            opponent_attack_duration=self.opponent_attack_duration,
+                            opponent_attack_cooldown=self.opponent_attack_cooldown,
+                            kwargs_opponent=self.opponent_kwargs,
+
+                            with_forecast=self.with_forecast,
+
+                            _raw_backend_class=self.backendClass
+                            )
 
         if self.thermal_limit_a is not None:
             res.set_thermal_limit(self.thermal_limit_a)
@@ -527,7 +564,7 @@ class Runner(object):
         else:
             self.env.reset()
 
-    def run_one_episode(self, indx=0, path_save=None, pbar=False, seed=None, max_iter=None):
+    def run_one_episode(self, indx=0, path_save=None, pbar=False, env_seed=None, max_iter=None, agent_seed=None):
         """
         Function used to run one episode of the :attr:`Runner.agent` and see how it performs in the :attr:`Runner.env`.
 
@@ -552,11 +589,12 @@ class Runner(object):
         """
         self.reset()
         res = self._run_one_episode(self.env, self.agent, self.logger, indx, path_save,
-                                    pbar=pbar, seed=seed, max_iter=max_iter)
+                                    pbar=pbar, env_seed=env_seed, max_iter=max_iter, agent_seed=agent_seed)
         return res
 
     @staticmethod
-    def _run_one_episode(env, agent, logger, indx, path_save=None, pbar=False, seed=None, max_iter=None):
+    def _run_one_episode(env, agent, logger, indx, path_save=None,
+                         pbar=False, env_seed=None, agent_seed=None, max_iter=None):
         done = False
         time_step = int(0)
         time_act = 0.
@@ -567,8 +605,8 @@ class Runner(object):
         # the "-1" above is because the environment will be reset. So it will increase id of 1.
 
         # set the seed
-        if seed is not None:
-            env.seed(seed)
+        if env_seed is not None:
+            env.seed(env_seed)
 
         # handle max_iter
         if max_iter is not None:
@@ -577,7 +615,9 @@ class Runner(object):
         # reset it
         obs = env.reset()
 
-        # reset the agent
+        # seed and reset the agent
+        if agent_seed is not None:
+            agent.seed(agent_seed)
         agent.reset(obs)
 
         # compute the size and everything if it needs to be stored
@@ -589,6 +629,11 @@ class Runner(object):
             # i don't store anything on drive, so i don't need to store anything on memory
             nb_timestep_max = 0
 
+        disc_lines_templ = np.full(
+            (1, env.backend.n_line), fill_value=False, dtype=dt_bool)
+
+        attack_templ = np.full(
+            (1, env.oppSpace.action_space.size()), fill_value=0., dtype=dt_float)
         if efficient_storing:
             times = np.full(nb_timestep_max, fill_value=np.NaN, dtype=dt_float)
             rewards = np.full(nb_timestep_max, fill_value=np.NaN, dtype=dt_float)
@@ -600,8 +645,7 @@ class Runner(object):
                 (nb_timestep_max+1, env.observation_space.n), fill_value=np.NaN, dtype=dt_float)
             disc_lines = np.full(
                 (nb_timestep_max, env.backend.n_line), fill_value=np.NaN, dtype=dt_bool)
-            disc_lines_templ = np.full(
-                (1, env.backend.n_line), fill_value=False, dtype=dt_bool)
+            attack = np.full((nb_timestep_max, env.opponent_action_space.n), fill_value=0., dtype=dt_float)
         else:
             times = np.full(0, fill_value=np.NaN, dtype=dt_float)
             rewards = np.full(0, fill_value=np.NaN, dtype=dt_float)
@@ -609,7 +653,7 @@ class Runner(object):
             env_actions = np.full((0, env.helper_action_env.n), fill_value=np.NaN, dtype=dt_float)
             observations = np.full((0, env.observation_space.n), fill_value=np.NaN, dtype=dt_float)
             disc_lines = np.full((0, env.backend.n_line), fill_value=np.NaN, dtype=dt_bool)
-            disc_lines_templ = np.full( (1, env.backend.n_line), fill_value=False, dtype=dt_bool)
+            attack = np.full((0, env.opponent_action_space.n), fill_value=0., dtype=dt_float)
 
         if path_save is not None:
             # store observation at timestep 0
@@ -629,6 +673,9 @@ class Runner(object):
                               helper_action_env=env.helper_action_env,
                               path_save=path_save,
                               disc_lines_templ=disc_lines_templ,
+                              attack_templ=attack_templ,
+                              attack=attack,
+                              attack_space=env.opponent_action_space,
                               logger=logger,
                               name=env.chronics_handler.get_name(),
                               other_rewards=[])
@@ -652,12 +699,14 @@ class Runner(object):
                 cum_reward += reward
                 time_step += 1
                 pbar_.update(1)
-
+                opp_attack = env.oppSpace.last_attack
                 episode.incr_store(efficient_storing, time_step, end__ - beg__,
-                                   float(reward), env.env_modification, act, obs, info)
+                                   float(reward), env.env_modification,
+                                   act, obs, opp_attack,
+                                   info)
             end_ = time.time()
 
-        episode.set_meta(env, time_step, float(cum_reward), seed)
+        episode.set_meta(env, time_step, float(cum_reward), env_seed, agent_seed)
 
         li_text = ["Env: {:.2f}s", "\t - apply act {:.2f}s", "\t - run pf: {:.2f}s",
                    "\t - env update + observation: {:.2f}s", "Agent: {:.2f}s", "Total time: {:.2f}s",
@@ -710,7 +759,7 @@ class Runner(object):
             pbar_ = pbar
         return pbar_
 
-    def run_sequential(self, nb_episode, path_save=None, pbar=False, seeds=None, max_iter=None):
+    def _run_sequential(self, nb_episode, path_save=None, pbar=False, env_seeds=None, agent_seeds=None, max_iter=None):
         """
         This method is called to see how well an agent performed on a sequence of episode.
 
@@ -735,7 +784,7 @@ class Runner(object):
             - if pbar is an object (an instance of a class) it is used to make a progress bar at this highest level
               (episode) but not at lower levels (setp during the episode)
 
-        seeds: ``list``
+        env_seeds: ``list``
             An iterable of the seed used for the experiments. By default ``None``, no seeds are set. If provided,
             its size should match ``nb_episode``.
 
@@ -756,13 +805,17 @@ class Runner(object):
         next_pbar = [False]
         with self._make_progress_bar(pbar, nb_episode, next_pbar) as pbar_:
             for i in range(nb_episode):
-                seed = None
-                if seeds is not None:
-                    seed = seeds[i]
+                env_seed = None
+                if env_seeds is not None:
+                    env_seed = env_seeds[i]
+                agt_seed = None
+                if agent_seeds is not None:
+                    agt_seed = agent_seeds[i]
                 name_chron, cum_reward, nb_time_step = self.run_one_episode(path_save=path_save,
                                                                             indx=i,
                                                                             pbar=next_pbar[0],
-                                                                            seed=seed,
+                                                                            env_seed=env_seed,
+                                                                            agent_seed=agt_seed,
                                                                             max_iter=max_iter)
                 id_chron = self.chronics_handler.get_id()
                 max_ts = self.chronics_handler.max_timestep()
@@ -771,7 +824,8 @@ class Runner(object):
         return res
 
     @staticmethod
-    def _one_process_parrallel(runner, episode_this_process, process_id, path_save=None, seeds=None, max_iter=None):
+    def _one_process_parrallel(runner, episode_this_process, process_id, path_save=None,
+                               env_seeds=None, max_iter=None, agent_seeds=None):
         chronics_handler = ChronicsHandler(chronicsClass=runner.gridStateclass,
                                            path=runner.path_chron,
                                            **runner.gridStateclass_kwargs)
@@ -783,17 +837,20 @@ class Runner(object):
             env, agent = runner._new_env(chronics_handler=chronics_handler,
                                          backend=backend,
                                          parameters=parameters)
-            seed = None
-            if seeds is not None:
-                seed = seeds[i]
+            env_seed = None
+            if env_seeds is not None:
+                env_seed = env_seeds[i]
+            agt_seed = None
+            if agent_seeds is not None:
+                agt_seed = agent_seeds[i]
             name_chron, cum_reward, nb_time_step = Runner._run_one_episode(
-                env, agent, runner.logger, p_id, path_save, seed=seed, max_iter=max_iter)
+                env, agent, runner.logger, p_id, path_save, env_seed=env_seed, max_iter=max_iter, agent_seed=agt_seed)
             id_chron = chronics_handler.get_id()
             max_ts = chronics_handler.max_timestep()
             res[i] = (id_chron, name_chron, float(cum_reward), nb_time_step, max_ts)
         return res
 
-    def run_parrallel(self, nb_episode, nb_process=1, path_save=None, seeds=None, max_iter=None):
+    def _run_parrallel(self, nb_episode, nb_process=1, path_save=None, env_seeds=None, agent_seeds=None, max_iter=None):
         """
         This method will run in parrallel, independantly the nb_episode over nb_process.
 
@@ -820,10 +877,15 @@ class Runner(object):
             If not None, it specifies where to store the data. See the description of this module :mod:`Runner` for
             more information
 
-        seeds: ``list``
+        env_seeds: ``list``
             An iterable of the seed used for the experiments. By default ``None``, no seeds are set. If provided,
             its size should match ``nb_episode``.
 
+        agent_seeds: ``list``
+            An iterable that contains the seed used for the environment. By default ``None`` means no seeds are set.
+            If provided, its size should match the ``nb_episode``. The agent will be seeded at the beginning of each
+            scenario BEFORE calling `agent.reset()`.
+
         Returns
         -------
         res: ``list``
@@ -839,14 +901,14 @@ class Runner(object):
         if nb_process <= 0:
             raise RuntimeError(
                 "Runner: you need at least 1 process to run episodes")
-        if nb_process == 1 or self.__can_copy_agent is False:
-            warnings.warn(
-                "Runner.run_parrallel: number of process set to 1. Failing back into sequential mod.")
-            return [self.run_sequential(nb_episode, path_save=path_save, seeds=seeds)]
+        if _IS_WINDOWS or nb_process == 1 or self.__can_copy_agent is False:
+            # on windows if i start using sequential, i need to continue using sequential
+            # if i start using parallel i need to continue using parallel
+            # so i force the usage of the sequential mode
+            self.logger.warn("Runner.run_parrallel: number of process set to 1. Failing back into sequential mod.")
+            return self._run_sequential(nb_episode, path_save=path_save, env_seeds=env_seeds, agent_seeds=agent_seeds)
         else:
-            if self.env is not None:
-                self.env.close()
-                self.env = None
+            self._clean_up()
             self.backend = self.backendClass()
 
             nb_process = int(nb_process)
@@ -854,13 +916,21 @@ class Runner(object):
             for i in range(nb_episode):
                 process_ids[i % nb_process].append(i)
 
-            if seeds is None:
+            if env_seeds is None:
                 seeds_res = [None for _ in range(nb_process)]
             else:
                 # split the seeds according to the process
                 seeds_res = [[] for i in range(nb_process)]
                 for i in range(nb_episode):
-                    seeds_res[i % nb_process].append(seeds[i])
+                    seeds_res[i % nb_process].append(env_seeds[i])
+
+            if agent_seeds is None:
+                seeds_agt_res = [None for _ in range(nb_process)]
+            else:
+                # split the seeds according to the process
+                seeds_agt_res = [[] for i in range(nb_process)]
+                for i in range(nb_episode):
+                    seeds_agt_res[i % nb_process].append(agent_seeds[i])
 
             res = []
             with Pool(nb_process) as p:
@@ -870,7 +940,13 @@ class Runner(object):
                 res += el
         return res
 
-    def run(self, nb_episode, nb_process=1, path_save=None, max_iter=None, pbar=False, seeds=None):
+    def _clean_up(self):
+        """close the environment is it has been created"""
+        if self.env is not None:
+            self.env.close()
+        self.env = None
+
+    def run(self, nb_episode, nb_process=1, path_save=None, max_iter=None, pbar=False, env_seeds=None, agent_seeds=None):
         """
         Main method of the :class:`Runner` class. It will either call :func:`Runner.run_sequential` if "nb_process" is
         1 or :func:`Runner.run_parrallel` if nb_process >= 2.
@@ -881,7 +957,8 @@ class Runner(object):
             Number of episode to simulate
 
         nb_process: ``int``, optional
-            Number of process used to play the nb_episode. Default to 1.
+            Number of process used to play the nb_episode. Default to 1. **NB** Multitoprocessing is deactivated
+            on windows based platform (it was not fully supported so we decided to remove it)
 
         path_save: ``str``, optional
             If not None, it specifies where to store the data. See the description of this module :mod:`Runner` for
@@ -902,10 +979,15 @@ class Runner(object):
             - if pbar is an object (an instance of a class) it is used to make a progress bar at this highest level
               (episode) but not at lower levels (setp during the episode)
 
-        seeds: ``list``
-            An iterable of the seed used for the experiments. By default ``None``, no seeds are set. If provided,
+        env_seeds: ``list``
+            An iterable of the seed used for the environment. By default ``None``, no seeds are set. If provided,
             its size should match ``nb_episode``.
 
+        agent_seeds: ``list``
+            An iterable that contains the seed used for the environment. By default ``None`` means no seeds are set.
+            If provided, its size should match the ``nb_episode``. The agent will be seeded at the beginning of each
+            scenario BEFORE calling `agent.reset()`.
+
         Returns
         -------
         res: ``list``
@@ -916,14 +998,64 @@ class Runner(object):
               - "cum_reward" the cumulative reward obtained by the :attr:`Runner.BaseAgent` on this episode i
               - "nb_time_step": the number of time steps played in this episode.
 
+        Examples
+        --------
+
+        You can use the runner this way:
+
+        .. code-block: python
+
+            import grid2op
+            from gri2op.Runner import Runner
+            from grid2op.Agent import RandomAgent
+
+            env = grid2op.make()
+            runner = Runner(**env.get_params_for_runner(), agentClass=RandomAgent)
+            res = runner.run(nb_episode=1)
+
+        If you would rather to provide an agent instance (and not a class) you can do it this way:
+
+        .. code-block: python
+
+            import grid2op
+            from gri2op.Runner import Runner
+            from grid2op.Agent import RandomAgent
+
+            env = grid2op.make()
+            my_agent = RandomAgent(env.action_space)
+            runner = Runner(**env.get_params_for_runner(), agentClass=None, agentInstance=my_agent)
+            res = runner.run(nb_episode=1)
+
+        Finally, in the presence of stochastic environments or stochastic agent you might want to set the seeds for
+        ensuring reproducible experiments you might want to seed both the environment and your agent. You can do that
+        by passing `env_seeds` and `agent_seeds` parameters (on the example bellow, the agent will be seeded with 42
+        and the environment with 0.
+
+        .. code-block: python
+
+            import grid2op
+            from gri2op.Runner import Runner
+            from grid2op.Agent import RandomAgent
+
+            env = grid2op.make()
+            my_agent = RandomAgent(env.action_space)
+            runner = Runner(**env.get_params_for_runner(), agentClass=None, agentInstance=my_agent)
+            res = runner.run(nb_episode=1, agent_seeds=[42], env_seeds=[0])
+
         """
         if nb_episode < 0:
             raise RuntimeError("Impossible to run a negative number of scenarios.")
 
-        if seeds is not None:
-            if len(seeds) != nb_episode:
-                raise RuntimeError("You want to compute \"{}\" run(s) but provide only \"{}\" different seeds."
-                                   "".format(nb_episode, len(seeds)))
+        if env_seeds is not None:
+            if len(env_seeds) != nb_episode:
+                raise RuntimeError("You want to compute \"{}\" run(s) but provide only \"{}\" different seeds "
+                                   "(environment)."
+                                   "".format(nb_episode, len(env_seeds)))
+
+        if agent_seeds is not None:
+            if len(agent_seeds) != nb_episode:
+                raise RuntimeError("You want to compute \"{}\" run(s) but provide only \"{}\" different seeds (agent)."
+                                   "".format(nb_episode, len(agent_seeds)))
 
         if max_iter is not None:
             max_iter = int(max_iter)
@@ -931,14 +1063,21 @@ class Runner(object):
         if nb_episode == 0:
             res = []
         else:
-            if nb_process <= 0:
-                raise RuntimeError("Impossible to run using less than 1 process.")
+            try:
+                if nb_process <= 0:
+                    raise RuntimeError("Impossible to run using less than 1 process.")
 
-            if nb_process == 1:
-                self.logger.info("Sequential runner used.")
-                res = self.run_sequential(nb_episode, path_save=path_save, pbar=pbar, seeds=seeds, max_iter=max_iter)
-            else:
-                self.logger.info("Parallel runner used.")
-                res = self.run_parrallel(nb_episode, nb_process=nb_process, path_save=path_save, seeds=seeds,
-                                         max_iter=max_iter)
+                if _IS_WINDOWS and nb_process > 1:
+                    self.logger.warn("Parallel run are not fully supported on windows at the moment. So we decided "
+                                     "to fully deactivate them.")
+                if nb_process == 1 or _IS_WINDOWS:
+                    self.logger.info("Sequential runner used.")
+                    res = self._run_sequential(nb_episode, path_save=path_save, pbar=pbar,
+                                               env_seeds=env_seeds, max_iter=max_iter, agent_seeds=agent_seeds)
+                else:
+                    self.logger.info("Parallel runner used.")
+                    res = self._run_parrallel(nb_episode, nb_process=nb_process, path_save=path_save,
+                                              env_seeds=env_seeds, max_iter=max_iter, agent_seeds=agent_seeds)
+            finally:
+                self._clean_up()
         return res
