@@ -275,6 +275,30 @@ class TestOtherReward(unittest.TestCase):
         assert "test" in info_simu["rewards"]
         assert np.abs(info_simu["rewards"]["test"] - reward_simu) <= self.tol_one
 
+    def test_copy(self):
+        # https://github.com/BDonnot/lightsim2grid/issues/10
+        for i in range(5):
+            obs, reward, done, info = self.env.step(self.env.action_space())
+        env2 = self.env.copy()
+
+        obsnew = env2.get_obs()
+        assert obsnew == obs
+
+        # after the same action, the original env and its copy are the same
+        obs0, reward0, done0, info0 = self.env.step(self.env.action_space())
+        obs1, reward1, done1, info1 = env2.step(env2.action_space())
+        assert obs0 == obs1
+        assert reward0 == reward1
+        assert done1 == done0
+
+        # reset has the correct behaviour
+        obs_after = env2.reset()
+        obs00, reward00, done00, info00 = self.env.step(self.env.action_space())
+        # i did not affect the other environment
+        assert obs00.minute_of_hour == obs0.minute_of_hour + self.env.chronics_handler.time_interval.seconds // 60
+        # reset read the right chronics
+        assert obs_after.minute_of_hour == 0
+
 
 class TestResetOk(unittest.TestCase):
     """
